@@ -14,7 +14,7 @@ our @ISA    = qw(Exporter);    ## no critic (ISA)
 our @EXPORT = qw( binsearch binsearch_pos ); ## no critic (export)
 
 
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 # $VERSION = eval $VERSION;  ## no critic (eval)
 
 
@@ -26,10 +26,11 @@ sub binsearch (&$\@) {
     my ( $code, $target, $aref ) = @_;
     my $min = 0;
     my $max = $#{$aref};
+    my $caller = caller();
     while ( $max > $min ) {
-        my $mid = int( ( $min + $max ) / 2 );
+        my $mid = int( ( $max - $min ) / 2 + $min );
         no strict 'refs'; ## no critic(strict)
-        local ( ${caller() . '::a'}, ${caller() . '::b'} )
+        local ( ${"${caller}::a"}, ${"${caller}::b"} )
           = ( $target, $aref->[$mid] );
         if ( $code->( $target, $aref->[$mid] ) > 0 ) {
             $min = $mid + 1;
@@ -40,7 +41,7 @@ sub binsearch (&$\@) {
     }
     {
       no strict 'refs'; ## no critic(strict)
-      local ( ${caller() . '::a'}, ${caller() . '::b'} )
+      local ( ${"${caller}::a"}, ${"${caller}::b"} )
         = ( $target, $aref->[$min] );
       return $min if $code->( $target, $aref->[$min] ) == 0;
     }
@@ -56,10 +57,11 @@ sub binsearch (&$\@) {
 sub binsearch_pos (&$\@) {
     my ( $comp, $target, $aref ) = @_;
     my ( $low, $high ) = ( 0, scalar @{$aref} );
+    my $caller = caller();
     while ( $low < $high ) {
-        my $cur = int( ( $low + $high ) / 2 );
+        my $cur = int( ( $high - $low ) / 2 + $low );
         no strict 'refs';  ## no critic(strict)
-        local ( ${ caller() . '::a'}, ${ caller() . '::b'} )
+        local ( ${"${caller}::a"}, ${"${caller}::b"} )
           = ( $target, $aref->[$cur] );                            # Future use.
         if ( $comp->( $target, $aref->[$cur] ) > 0 ) {
             $low = $cur + 1;
